<?php

namespace Litecms\Loantype\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Litecms\Loantype\Interfaces\LoantypeRepositoryInterface;

class LoantypePublicController extends BaseController
{
    // use LoantypeWorkflow;

    /**
     * Constructor.
     *
     * @param type \Litecms\Loantype\Interfaces\LoantypeRepositoryInterface $loantype
     *
     * @return type
     */
    public function __construct(LoantypeRepositoryInterface $loantype)
    {
        $this->repository = $loantype;
        parent::__construct();
    }

    /**
     * Show loantype's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $loantypes = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$loantype::$loantype.names'))
            ->view('$loantype::public.loantype.index')
            ->data(compact('$loantypes'))
            ->output();
    }

    /**
     * Show loantype's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $loantypes = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$loantype::$loantype.names'))
            ->view('$loantype::public.loantype.index')
            ->data(compact('$loantypes'))
            ->output();
    }

    /**
     * Show loantype.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $loantype = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$loantype->name . trans('$loantype::$loantype.name'))
            ->view('$loantype::public.loantype.show')
            ->data(compact('$loantype'))
            ->output();
    }

}
