<?php

namespace Litecms\Loantype\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Loantype\Models\Loantype;

class LoantypePolicy
{

    /**
     * Determine if the given user can view the loantype.
     *
     * @param UserPolicy $user
     * @param Loantype $loantype
     *
     * @return bool
     */
    public function view(UserPolicy $user, Loantype $loantype)
    {
        if ($user->canDo('loantype.loantype.view') && $user->isAdmin()) {
            return true;
        }

        return $loantype->user_id == user_id() && $loantype->user_type == user_type();
    }

    /**
     * Determine if the given user can create a loantype.
     *
     * @param UserPolicy $user
     * @param Loantype $loantype
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('loantype.loantype.create');
    }

    /**
     * Determine if the given user can update the given loantype.
     *
     * @param UserPolicy $user
     * @param Loantype $loantype
     *
     * @return bool
     */
    public function update(UserPolicy $user, Loantype $loantype)
    {
        if ($user->canDo('loantype.loantype.edit') && $user->isAdmin()) {
            return true;
        }

        return $loantype->user_id == user_id() && $loantype->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given loantype.
     *
     * @param UserPolicy $user
     * @param Loantype $loantype
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Loantype $loantype)
    {
        return $loantype->user_id == user_id() && $loantype->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given loantype.
     *
     * @param UserPolicy $user
     * @param Loantype $loantype
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Loantype $loantype)
    {
        if ($user->canDo('loantype.loantype.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given loantype.
     *
     * @param UserPolicy $user
     * @param Loantype $loantype
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Loantype $loantype)
    {
        if ($user->canDo('loantype.loantype.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
