<?php

namespace Litecms\Loantype\Providers;

use Illuminate\Support\ServiceProvider;

class LoantypeServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'loantype');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'loantype');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.loantype', function ($app) {
            return $this->app->make('Litecms\Loantype\Loantype');
        });

                // Bind Loantype to repository
        $this->app->bind(
            'Litecms\Loantype\Interfaces\LoantypeRepositoryInterface',
            \Litecms\Loantype\Repositories\Eloquent\LoantypeRepository::class
        );

        $this->app->register(\Litecms\Loantype\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Loantype\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.loantype'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/loantype.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/loantype')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/loantype')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
